summaryrefslogtreecommitdiffstats
path: root/sys/net80211/ieee80211_var.h
diff options
context:
space:
mode:
authorsam <sam@FreeBSD.org>2009-06-04 15:57:38 +0000
committersam <sam@FreeBSD.org>2009-06-04 15:57:38 +0000
commite673d3b5e90d6ec6fe0c6bca82c4b813b1af6e3d (patch)
tree0087ddfa0d20ea5694d61834bf30fbd8cf190b9f /sys/net80211/ieee80211_var.h
parent981682577c61c5ffe81deb34e9b9b1f0658c7fb0 (diff)
downloadFreeBSD-src-e673d3b5e90d6ec6fe0c6bca82c4b813b1af6e3d.zip
FreeBSD-src-e673d3b5e90d6ec6fe0c6bca82c4b813b1af6e3d.tar.gz
o station mode channel switch support
o IEEE80211_IOC_CHANSWITCH fixups: - restrict to hostap vaps - return EOPNOTSUPP instead of EINVAL when applied to !hostap vap or to a vap w/o 11h enabled - interpret count of 0 to mean cancel the current CSA Reviewed by: rpaulo, avatar
Diffstat (limited to 'sys/net80211/ieee80211_var.h')
-rw-r--r--sys/net80211/ieee80211_var.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/sys/net80211/ieee80211_var.h b/sys/net80211/ieee80211_var.h
index 3e999c8..df7575f 100644
--- a/sys/net80211/ieee80211_var.h
+++ b/sys/net80211/ieee80211_var.h
@@ -181,7 +181,8 @@ struct ieee80211com {
/* 802.11h/DFS state */
struct ieee80211_channel *ic_csa_newchan;/* channel for doing CSA */
- int ic_csa_count; /* count for doing CSA */
+ short ic_csa_mode; /* mode for doing CSA */
+ short ic_csa_count; /* count for doing CSA */
struct ieee80211_dfs_state ic_dfs; /* DFS state */
struct ieee80211_scan_state *ic_scan; /* scan state */
OpenPOWER on IntegriCloud